# apache-airflow-providers-box

Provider for integrating Box.com with Apache Airflow. Written for Apache Airflow 2.11.0.

See the [sample basic.py DAG](dags/basic.py) for usage examples.

## Support

This product is supported by the Graduate College, University of Illinois Urbana-Champaign on a best-effort basis.

As of the last update to this README, the expected End-of-Life and End-of-Support dates 
of this product are 2026-04-22.

End-of-Life was decided upon based on these dependencies:

- Box SDK Gen (v10+): [Box SDK v10 EOL is TBD](https://github.com/box/box-python-sdk?tab=readme-ov-file#versioning)
- Apache Airflow 2.11: 2026-04-22
- Python 3.12: 2028-08-31
